emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] trunk r116625: Consider Vother_window_scroll_buffer valid


From: Martin Rudalics
Subject: [Emacs-diffs] trunk r116625: Consider Vother_window_scroll_buffer valid iff it's a live buffer.
Date: Sat, 01 Mar 2014 19:15:40 +0000
User-agent: Bazaar (2.6b2)

------------------------------------------------------------
revno: 116625
revision-id: address@hidden
parent: address@hidden
committer: martin rudalics <address@hidden>
branch nick: trunk
timestamp: Sat 2014-03-01 20:15:29 +0100
message:
  Consider Vother_window_scroll_buffer valid iff it's a live buffer.
  
  * window.c (Fother_window_for_scrolling): Don't try to scroll a
  killed Vother_window_scroll_buffer.
  (Vother_window_scroll_buffer): Fix doc-string accordingly.
modified:
  src/ChangeLog                  changelog-20091113204419-o5vbwnq5f7feedwu-1438
  src/window.c                   window.c-20091113204419-o5vbwnq5f7feedwu-231
=== modified file 'src/ChangeLog'
--- a/src/ChangeLog     2014-03-01 11:51:02 +0000
+++ b/src/ChangeLog     2014-03-01 19:15:29 +0000
@@ -1,3 +1,10 @@
+2014-03-01  Martin Rudalics  <address@hidden>
+
+       Consider Vother_window_scroll_buffer valid iff it's a live buffer.
+       * window.c (Fother_window_for_scrolling): Don't try to scroll a
+       killed Vother_window_scroll_buffer.
+       (Vother_window_scroll_buffer): Fix doc-string accordingly.
+
 2014-03-01  Eli Zaretskii  <address@hidden>
 
        * fileio.c (Fexpand_file_name) [WINDOWSNT]: Don't treat file names

=== modified file 'src/window.c'
--- a/src/window.c      2014-02-27 19:22:10 +0000
+++ b/src/window.c      2014-03-01 19:15:29 +0000
@@ -5429,8 +5429,9 @@
   if (MINI_WINDOW_P (XWINDOW (selected_window))
       && !NILP (Vminibuf_scroll_window))
     window = Vminibuf_scroll_window;
-  /* If buffer is specified, scroll that buffer.  */
-  else if (!NILP (Vother_window_scroll_buffer))
+  /* If buffer is specified and live, scroll that buffer.  */
+  else if (!NILP (Vother_window_scroll_buffer)
+          && BUFFER_LIVE_P (XBUFFER (Vother_window_scroll_buffer)))
     {
       window = Fget_buffer_window (Vother_window_scroll_buffer, Qnil);
       if (NILP (window))
@@ -7197,7 +7198,7 @@
   mode_line_in_non_selected_windows = 1;
 
   DEFVAR_LISP ("other-window-scroll-buffer", Vother_window_scroll_buffer,
-              doc: /* If non-nil, this is a buffer and \\[scroll-other-window] 
should scroll its window.  */);
+              doc: /* If this is a live buffer, \\[scroll-other-window] should 
scroll its window.  */);
   Vother_window_scroll_buffer = Qnil;
 
   DEFVAR_BOOL ("auto-window-vscroll", auto_window_vscroll_p,


reply via email to

[Prev in Thread] Current Thread [Next in Thread]